"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const node_assert_1 = require("node:assert");
const internal_1 = require("@fluidframework/test-runtime-utils/internal");
const deltaManagerProxies_js_1 = require("../deltaManagerProxies.js");
describe("DeltaManagerSummarizerProxy", () => {
    it("should not wrap non-summarizers", () => {
        const mockDeltaManager = new internal_1.MockDeltaManager();
        const proxy = deltaManagerProxies_js_1.DeltaManagerSummarizerProxy.wrapIfSummarizer(mockDeltaManager);
        node_assert_1.strict.equal(proxy, mockDeltaManager);
    });
    it("should override active and readOnlyInfo properties", () => {
        const mockDeltaManager = new internal_1.MockDeltaManager();
        mockDeltaManager.clientDetails.type = "summarizer";
        const proxy = deltaManagerProxies_js_1.DeltaManagerSummarizerProxy.wrapIfSummarizer(mockDeltaManager);
        node_assert_1.strict.equal(proxy.active, false, "active should be false for summarizer");
        node_assert_1.strict.equal(proxy.readOnlyInfo.readonly, true, "readOnlyInfo.readonly should be true for summarizer");
    });
    it("should not emit readonly event when underlying delta manager emits it", () => {
        const mockDeltaManager = new internal_1.MockDeltaManager();
        mockDeltaManager.clientDetails.type = "summarizer";
        const proxy = deltaManagerProxies_js_1.DeltaManagerSummarizerProxy.wrapIfSummarizer(mockDeltaManager);
        let eventTriggered = false;
        proxy.on("readonly", () => {
            eventTriggered = true;
        });
        mockDeltaManager.emit("readonly", false, { reason: "Test reason" });
        node_assert_1.strict.equal(eventTriggered, false, "readonly event should not be triggered");
        node_assert_1.strict.equal(proxy.readOnlyInfo.readonly, true, "readOnlyInfo.readonly should be true for summarizer");
    });
    it("should handle active state changes correctly", () => {
        const mockDeltaManager = new internal_1.MockDeltaManager();
        mockDeltaManager.clientDetails.type = "summarizer";
        const proxy = deltaManagerProxies_js_1.DeltaManagerSummarizerProxy.wrapIfSummarizer(mockDeltaManager);
        mockDeltaManager.active = false;
        node_assert_1.strict.equal(proxy.active, false, "active should initially be false for summarizer");
        mockDeltaManager.active = true;
        node_assert_1.strict.equal(proxy.active, false, "proxy should alway report active as false");
    });
    it("should handle readonly state changes correctly", () => {
        const mockDeltaManager = new internal_1.MockDeltaManager();
        mockDeltaManager.clientDetails.type = "summarizer";
        const proxy = deltaManagerProxies_js_1.DeltaManagerSummarizerProxy.wrapIfSummarizer(mockDeltaManager);
        mockDeltaManager.readOnlyInfo = {
            readonly: true,
            forced: false,
            permissions: undefined,
            storageOnly: false,
        };
        node_assert_1.strict.equal(proxy.readOnlyInfo.readonly, true, "readonly should initially be true for summarizer");
        mockDeltaManager.readOnlyInfo = { readonly: false };
        node_assert_1.strict.equal(proxy.readOnlyInfo.readonly, true, "readonly should remain true for summarizer");
    });
});
//# sourceMappingURL=deltaManagerProxies.spec.js.map