"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const node_assert_1 = require("node:assert");
const runCounter_js_1 = require("../runCounter.js");
describe("RunCounter", () => {
    it("should start with zero runs", () => {
        const runCounter = new runCounter_js_1.RunCounter();
        node_assert_1.strict.strictEqual(runCounter.runs, 0);
        node_assert_1.strict.strictEqual(runCounter.running, false);
    });
    it("should increment runs when running", () => {
        const runCounter = new runCounter_js_1.RunCounter();
        runCounter.run(() => {
            node_assert_1.strict.strictEqual(runCounter.runs, 1);
            node_assert_1.strict.strictEqual(runCounter.running, true);
        });
        node_assert_1.strict.strictEqual(runCounter.runs, 0);
        node_assert_1.strict.strictEqual(runCounter.running, false);
    });
    it("should handle nested runs correctly", () => {
        const runCounter = new runCounter_js_1.RunCounter();
        runCounter.run(() => {
            node_assert_1.strict.strictEqual(runCounter.runs, 1);
            runCounter.run(() => {
                node_assert_1.strict.strictEqual(runCounter.runs, 2);
            });
            node_assert_1.strict.strictEqual(runCounter.runs, 1);
        });
        node_assert_1.strict.strictEqual(runCounter.runs, 0);
    });
    it("should return the result of the action", () => {
        const runCounter = new runCounter_js_1.RunCounter();
        const result = runCounter.run(() => 42);
        node_assert_1.strict.strictEqual(result, 42);
    });
    it("should decrement runs even if the action throws", () => {
        const runCounter = new runCounter_js_1.RunCounter();
        node_assert_1.strict.throws(() => {
            runCounter.run(() => {
                throw new Error("test error");
            });
        }, /test error/);
        node_assert_1.strict.strictEqual(runCounter.runs, 0);
        node_assert_1.strict.strictEqual(runCounter.running, false);
    });
});
//# sourceMappingURL=runCounter.spec.js.map