/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { CreateSummarizerNodeSource, } from "@fluidframework/runtime-definitions/internal";
import { createChildLogger } from "@fluidframework/telemetry-utils/internal";
import { MockDeltaManager, MockFluidDataStoreRuntime, } from "@fluidframework/test-runtime-utils/internal";
import { LocalFluidDataStoreContext, } from "../dataStoreContext.js";
import { createRootSummarizerNodeWithGC, } from "../summary/index.js";
export function createParentContext(logger = createChildLogger(), clientDetailsOverrides, compatDetails) {
    const factory = {
        type: "store-type",
        get IFluidDataStoreFactory() {
            return factory;
        },
        instantiateDataStore: async (context) => {
            const mockDataStoreRuntime = new MockFluidDataStoreRuntime();
            if (compatDetails !== undefined) {
                mockDataStoreRuntime.ILayerCompatDetails = compatDetails;
            }
            return mockDataStoreRuntime;
        },
    };
    const registry = {
        get IFluidDataStoreRegistry() {
            return registry;
        },
        get: async (pkg) => (pkg === "BOGUS" ? undefined : factory),
    };
    const clientDetails = {
        capabilities: { interactive: true },
        ...clientDetailsOverrides,
    };
    return {
        IFluidDataStoreRegistry: registry,
        baseLogger: logger,
        clientDetails,
        submitMessage: () => { },
        deltaManager: new MockDeltaManager(),
        isReadOnly: () => !clientDetails.capabilities.interactive,
    };
}
export function createSummarizerNodeAndGetCreateFn(dataStoreId) {
    const summarizerNode = createRootSummarizerNodeWithGC(createChildLogger(), (() => undefined), 0, 0);
    summarizerNode.startSummary(0, createChildLogger(), 0);
    const createSummarizerNodeFn = (summarizeInternal, getGCDataFn) => summarizerNode.createChild(summarizeInternal, dataStoreId, { type: CreateSummarizerNodeSource.Local }, undefined, getGCDataFn);
    return { summarizerNode, createSummarizerNodeFn };
}
const defaultCreateProps = {
    id: "dataStoreId",
    pkg: ["dataStorePkg"],
    storage: {},
    scope: {},
    snapshotTree: undefined,
    makeLocallyVisibleFn: () => { },
};
export function createLocalDataStoreContext(props, compatDetails) {
    const localProps = {
        ...defaultCreateProps,
        ...props,
        parentContext: props.parentContext ?? createParentContext(undefined, undefined, compatDetails),
        createSummarizerNodeFn: props.createSummarizerNodeFn ??
            createSummarizerNodeAndGetCreateFn(props.id ?? defaultCreateProps.id)
                .createSummarizerNodeFn,
    };
    return new LocalFluidDataStoreContext(localProps);
}
//# sourceMappingURL=dataStoreCreationHelper.js.map